package com.ruoyi.project.production.service;

import java.util.List;
import com.ruoyi.project.production.domain.TPpePerson;

/**
 * 员工PPE检查Service接口
 *
 * @author ssy
 * @date 2023-11-28
 */
public interface ITPpePersonService
{
    /**
     * 查询员工PPE检查
     *
     * @param id 员工PPE检查ID
     * @return 员工PPE检查
     */
    public TPpePerson selectTPpePersonById(Long id);

    public TPpePerson selectTPpePersonByEmployeeid(String id);

    /**
     * 查询员工PPE检查列表
     *
     * @param tPpePerson 员工PPE检查
     * @return 员工PPE检查集合
     */
    public List<TPpePerson> selectTPpePersonList(TPpePerson tPpePerson);

    /**
     * 新增员工PPE检查
     *
     * @param tPpePerson 员工PPE检查
     * @return 结果
     */
    public int insertTPpePerson(TPpePerson tPpePerson);

    /**
     * 修改员工PPE检查
     *
     * @param tPpePerson 员工PPE检查
     * @return 结果
     */
    public int updateTPpePerson(TPpePerson tPpePerson);

    /**
     * 批量删除员工PPE检查
     *
     * @param ids 需要删除的员工PPE检查ID
     * @return 结果
     */
    public int deleteTPpePersonByIds(Long[] ids);

    /**
     * 删除员工PPE检查信息
     *
     * @param id 员工PPE检查ID
     * @return 结果
     */
    public int deleteTPpePersonById(Long id);
    public int deleteTPpePersonByShiftmgr();
}
